@@ -1,6 +1,6 @@
 import logging
 import time
-from typing import Callable, Dict, List, Optional, Tuple
+from typing import Dict, List, Optional, Protocol, Tuple
 
 import numpy.random as rnd
 
@@ -12,10 +12,25 @@ from alns.accept import AcceptanceCriterion
 from alns.select import OperatorSelectionScheme
 from alns.stop import StoppingCriterion
 
-# TODO these should become Protocol to allow for kwargs. See also this issue:
-#  https://stackoverflow.com/q/61569324/4316405.
-_OperatorType = Callable[[State, rnd.RandomState], State]
-_CallbackType = Callable[[State, rnd.RandomState], None]
+
+class _OperatorType(Protocol):
+    __name__: str
+
+    def __call__(
+        self,
+        state: State,
+        rnd_state: rnd.RandomState,
+        **kwargs,
+    ) -> State:
+        pass  # pragma: no cover
+
+
+class _CallbackType(Protocol):
+    __name__: str
+
+    def __call__(self, state: State, rnd_state: rnd.RandomState, **kwargs):
+        pass  # pragma: no cover
+
 
 logger = logging.getLogger(__name__)
 
@@ -183,7 +198,7 @@ class ALNS:
 
         .. [2] S. Røpke and D. Pisinger (2006). A unified heuristic for a large
                class of vehicle routing problems with backhauls. *European
-               Journal of Operational Research*, 171: 750–775.
+               Journal of Operational Research*, 171: 750-775.
         """
         if len(self.destroy_operators) == 0 or len(self.repair_operators) == 0:
             raise ValueError("Missing destroy or repair operators.")
