@@ -2,13 +2,12 @@ import logging
 
 import numpy as np
 
-from alns.accept.AcceptanceCriterion import AcceptanceCriterion
 from alns.accept.update import update
 
 logger = logging.getLogger(__name__)
 
 
-class SimulatedAnnealing(AcceptanceCriterion):
+class SimulatedAnnealing:
     R"""
     Simulated annealing, using an updating temperature.
 
@@ -53,7 +52,7 @@ class SimulatedAnnealing(AcceptanceCriterion):
     ----------
     .. [1] Santini, A., Ropke, S. & Hvattum, L.M. A comparison of acceptance
            criteria for the adaptive large neighbourhood search metaheuristic.
-           *Journal of Heuristics* (2018) 24 (5): 783–815.
+           *Journal of Heuristics* (2018) 24 (5): 783-815.
     .. [2] Kirkpatrick, S., Gerlatt, C. D. Jr., and Vecchi, M. P. Optimization
            by Simulated Annealing. *IBM Research Report* RC 9355, 1982.
     """
