@@ -1,9 +1,10 @@
 from .AcceptanceCriterion import AcceptanceCriterion
+from .AlwaysAccept import AlwaysAccept
 from .GreatDeluge import GreatDeluge
 from .HillClimbing import HillClimbing
 from .LateAcceptanceHillClimbing import LateAcceptanceHillClimbing
+from .MovingAverageThreshold import MovingAverageThreshold
 from .NonLinearGreatDeluge import NonLinearGreatDeluge
-from .RandomWalk import RandomWalk
+from .RandomAccept import RandomAccept
 from .RecordToRecordTravel import RecordToRecordTravel
 from .SimulatedAnnealing import SimulatedAnnealing
-from .WorseAccept import WorseAccept
