@@ -1,7 +1,5 @@
 import sys
-
-# TODO switch over to importlib.metadata once we drop support for Python 3.7
-import pkg_resources  # type: ignore
+from importlib.metadata import version
 
 
 def show_versions():
@@ -23,14 +21,11 @@ def show_versions():
     matplotlib: 3.5.1
         Python: 3.9.9
     """
-    alns = pkg_resources.get_distribution("alns")
-    numpy = pkg_resources.get_distribution("numpy")
-    matplotlib = pkg_resources.get_distribution("matplotlib")
     python_version = ".".join(map(str, sys.version_info[:3]))
 
     print("INSTALLED VERSIONS")
     print("------------------")
-    print(f"      alns: {alns.version}")
-    print(f"     numpy: {numpy.version}")
-    print(f"matplotlib: {matplotlib.version}")
+    print(f"      alns: {version('alns')}")
+    print(f"     numpy: {version('numpy')}")
+    print(f"matplotlib: {version('matplotlib')}")
     print(f"    Python: {python_version}")
